@@ -2,10 +2,12 @@ import argparse
 import logging
 import sys
 import warnings
+from functools import partial
 
 from decli import cli
 
-from commitizen import commands, config, out
+from commitizen import commands, config
+from commitizen.exceptions import CommitizenException, ExpectedExit, NoCommandFoundError
 
 logger = logging.getLogger(__name__)
 data = {
@@ -237,6 +239,24 @@ data = {
     },
 }
 
+original_excepthook = sys.excepthook
+
+
+def commitizen_excepthook(type, value, tracekback, debug=False):
+    if isinstance(value, CommitizenException):
+        if value.message:
+            value.output_method(value.message)
+        if debug:
+            original_excepthook(type, value, tracekback)
+        sys.exit(value.exit_code)
+    else:
+        original_excepthook(type, value, tracekback)
+
+
+commitizen_debug_excepthook = partial(commitizen_excepthook, debug=True)
+
+sys.excepthook = commitizen_excepthook
+
 
 def main():
     conf = config.read_cfg()
@@ -245,14 +265,13 @@ def main():
     # Show help if no arg provided
     if len(sys.argv) == 1:
         parser.print_help(sys.stderr)
-        raise SystemExit()
+        raise ExpectedExit()
 
     # This is for the command required constraint in 2.0
     try:
         args = parser.parse_args()
     except TypeError:
-        out.error("Command is required")
-        raise SystemExit()
+        raise NoCommandFoundError()
 
     if args.name:
         conf.update({"name": args.name})
@@ -270,19 +289,16 @@ def main():
         args.func = commands.Version
 
     if args.debug:
-        warnings.warn(
-            (
-                "Debug will be deprecated in next major version. "
-                "Please remove it from your scripts"
-            ),
-            category=DeprecationWarning,
-        )
         logging.getLogger("commitizen").setLevel(logging.DEBUG)
+        sys.excepthook = commitizen_debug_excepthook
 
     # TODO: This try block can be removed after command is required in 2.0
     # Handle the case that argument is given, but no command is provided
     try:
         args.func(conf, vars(args))()
     except AttributeError:
-        out.error("Command is required")
-        raise SystemExit()
+        raise NoCommandFoundError()
+
+
+if __name__ == "__main__":
+    main()
