@@ -6,12 +6,14 @@ from packaging.version import Version
 from commitizen import bump, factory, git, out
 from commitizen.commands.changelog import Changelog
 from commitizen.config import BaseConfig
-from commitizen.error_codes import (
-    COMMIT_FAILED,
-    NO_COMMITS_FOUND,
-    NO_PATTERN_MAP,
-    NO_VERSION_SPECIFIED,
-    TAG_FAILED,
+from commitizen.exceptions import (
+    BumpCommitFailedError,
+    BumpTagFailedError,
+    DryRunExit,
+    ExpectedExit,
+    NoCommitsFoundError,
+    NoPatternMapError,
+    NoVersionSpecifiedError,
 )
 
 
@@ -56,8 +58,9 @@ class Bump:
         bump_pattern = self.cz.bump_pattern
         bump_map = self.cz.bump_map
         if not bump_map or not bump_pattern:
-            out.error(f"'{self.config.settings['name']}' rule does not support bump")
-            raise SystemExit(NO_PATTERN_MAP)
+            raise NoPatternMapError(
+                f"'{self.config.settings['name']}' rule does not support bump"
+            )
         increment = bump.find_increment(
             commits, regex=bump_pattern, increments_map=bump_map
         )
@@ -68,12 +71,7 @@ class Bump:
         try:
             current_version_instance: Version = Version(self.bump_settings["version"])
         except TypeError:
-            out.error(
-                "[NO_VERSION_SPECIFIED]\n"
-                "Check if current version is specified in config file, like:\n"
-                "version = 0.4.3\n"
-            )
-            raise SystemExit(NO_VERSION_SPECIFIED)
+            raise NoVersionSpecifiedError()
 
         # Initialize values from sources (conf)
         current_version: str = self.config.settings["version"]
@@ -101,8 +99,7 @@ class Bump:
         # No commits, there is no need to create an empty tag.
         # Unless we previously had a prerelease.
         if not commits and not current_version_instance.is_prerelease:
-            out.error("[NO_COMMITS_FOUND]\n" "No new commits found.")
-            raise SystemExit(NO_COMMITS_FOUND)
+            raise NoCommitsFoundError("[NO_COMMITS_FOUND]\n" "No new commits found.")
 
         if increment is None:
             increment = self.find_increment(commits)
@@ -129,7 +126,7 @@ class Bump:
 
         # Do not perform operations over files or git.
         if dry_run:
-            raise SystemExit()
+            raise DryRunExit()
 
         bump.update_version_in_files(
             current_version,
@@ -138,7 +135,7 @@ class Bump:
             check_consistency=self.check_consistency,
         )
         if is_files_only:
-            raise SystemExit()
+            raise ExpectedExit()
 
         if self.changelog:
             changelog = Changelog(
@@ -154,12 +151,10 @@ class Bump:
         self.config.set_key("version", new_version.public)
         c = git.commit(message, args=self._get_commit_args())
         if c.err:
-            out.error('git.commit error: "{}"'.format(c.err.strip()))
-            raise SystemExit(COMMIT_FAILED)
+            raise BumpCommitFailedError(f'git.commit error: "{c.err.strip()}"')
         c = git.tag(new_tag_version)
         if c.err:
-            out.error(c.err)
-            raise SystemExit(TAG_FAILED)
+            raise BumpTagFailedError(c.err)
         out.success("Done!")
 
     def _get_commit_args(self):
