@@ -5,7 +5,12 @@ from typing import Callable, Dict, List, Optional
 
 from commitizen import changelog, factory, git, out
 from commitizen.config import BaseConfig
-from commitizen.error_codes import NO_COMMITS_FOUND, NO_PATTERN_MAP, NO_REVISION
+from commitizen.exceptions import (
+    DryRunExit,
+    NoCommitsFoundError,
+    NoPatternMapError,
+    NoRevisionError,
+)
 from commitizen.git import GitTag
 
 
@@ -51,9 +56,9 @@ class Changelog:
         try:
             score, tag = max(tag_ratio, key=itemgetter(0))
         except ValueError:
-            raise SystemExit(NO_REVISION)
+            raise NoRevisionError()
         if score < SIMILARITY_THRESHOLD:
-            raise SystemExit(NO_REVISION)
+            raise NoRevisionError()
         start_rev = tag.name
         return start_rev
 
@@ -68,12 +73,10 @@ class Changelog:
             Callable
         ] = self.cz.changelog_message_builder_hook
         changelog_hook: Optional[Callable] = self.cz.changelog_hook
-
         if not changelog_pattern or not commit_parser:
-            out.error(
+            raise NoPatternMapError(
                 f"'{self.config.settings['name']}' rule does not support changelog"
             )
-            raise SystemExit(NO_PATTERN_MAP)
 
         tags = git.get_tags()
         if not tags:
@@ -87,8 +90,7 @@ class Changelog:
 
         commits = git.get_commits(start=start_rev, args="--author-date-order")
         if not commits:
-            out.error("No commits found")
-            raise SystemExit(NO_COMMITS_FOUND)
+            raise NoCommitsFoundError("No commits found")
 
         tree = changelog.generate_tree_from_commits(
             commits,
@@ -104,7 +106,7 @@ class Changelog:
 
         if self.dry_run:
             out.write(changelog_out)
-            raise SystemExit(0)
+            raise DryRunExit()
 
         lines = []
         if self.incremental and os.path.isfile(self.file_name):
